@@ -37,8 +37,8 @@ static gchar *DefaultHeight = "Input|GtkWindow::default_height";
 static gchar *Shrink = "InputDialog|GtkWindow::allow_shrink";
 static gchar *Grow = "InputDialog|GtkWindow::allow_grow";
 static gchar *AutoShrink = "InputDialog|GtkWindow::auto_shrink";
-static gchar *WMName = "InputDialog|GtkWindow::wmclass_name";
-static gchar *WMClass = "InputDialog|GtkWindow::wmclass_class";
+static gchar *IconName = "InputDialog|GtkWindow::icon_name";
+static gchar *FocusOnMap = "InputDialog|GtkWindow::focus_on_map";
 
 static gchar *Resizable = "InputDialog|GtkWindow::resizable";
 static gchar *DestroyWithParent = "InputDialog|GtkWindow::destroy_with_parent";
@@ -87,6 +87,9 @@ gb_input_dialog_new (GbWidgetNewData *data)
 			 data->action == GB_CREATING ? "close_button" : NULL);
   gb_widget_set_child_name (inputdlg->close_button, GladeChildCloseButton);
 
+  gtk_object_set_data (GTK_OBJECT (new_widget), TypeHint,
+		       GINT_TO_POINTER (GLADE_TYPE_HINT_DIALOG_INDEX));
+
   return new_widget;
 }
 
@@ -102,7 +105,7 @@ gb_input_dialog_create_properties (GtkWidget * widget, GbWidgetCreateArgData * d
 					Title, Type, Position, Modal,
 					DefaultWidth, DefaultHeight,
 					Shrink, Grow, AutoShrink,
-					WMName, WMClass,
+					IconName, FocusOnMap,
 					Resizable, DestroyWithParent, Icon,
 					Role, TypeHint, SkipTaskbar,
 					SkipPager, Decorated, Gravity);
@@ -121,7 +124,7 @@ gb_input_dialog_get_properties (GtkWidget *widget, GbWidgetGetArgData * data)
 				     Title, Type, Position, Modal,
 				     DefaultWidth, DefaultHeight,
 				     Shrink, Grow, AutoShrink,
-				     WMName, WMClass,
+				     IconName, FocusOnMap,
 				     Resizable, DestroyWithParent, Icon,
 				     Role, TypeHint, SkipTaskbar,
 				     SkipPager, Decorated, Gravity);
@@ -140,7 +143,7 @@ gb_input_dialog_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 				     Title, Type, Position, Modal,
 				     DefaultWidth, DefaultHeight,
 				     Shrink, Grow, AutoShrink,
-				     WMName, WMClass,
+				     IconName, FocusOnMap,
 				     Resizable, DestroyWithParent, Icon,
 				     Role, TypeHint, SkipTaskbar,
 				     SkipPager, Decorated, Gravity);
@@ -184,7 +187,7 @@ gb_input_dialog_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data
 				   Title, Type, Position, Modal,
 				   DefaultWidth, DefaultHeight,
 				   Shrink, Grow, AutoShrink,
-				   WMName, WMClass,
+				   IconName, FocusOnMap,
 				   Resizable, DestroyWithParent, Icon,
 				   Role, TypeHint, SkipTaskbar,
 				   SkipPager, Decorated, Gravity);
